mod csv;

#[cfg(feature = "json")]
mod json;

#[cfg(feature = "parquet")]
mod parquet;

#[cfg(feature = "avro")]
mod avro;

#[cfg(feature = "ipc")]
mod ipc;
#[cfg(feature = "ipc_streaming")]
mod ipc_stream;

use polars::prelude::*;

pub(crate) fn create_df() -> DataFrame {
    let s0 = Column::new("days".into(), [0, 1, 2, 3, 4].as_ref());
    let s1 = Column::new("temp".into(), [22.1, 19.9, 7., 2., 3.].as_ref());
    DataFrame::new_infer_height(vec![s0, s1]).unwrap()
}
